@@ -1,4 +1,3 @@
-/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * ***** BEGIN LICENSE BLOCK *****
  * Version: MIT
@@ -37,29 +36,28 @@
  * ***** END LICENSE BLOCK *****
  */
 
-#include <stdlib.h>
+#include <stdint.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
-#include <stdint.h>
 #include <amqp.h>
 #include <amqp_tcp_socket.h>
 
 #include <assert.h>
 
 #ifdef _WIN32
-# ifndef WIN32_LEAN_AND_MEAN
-#  define WIN32_LEAN_AND_MEAN
-# endif
-# include <Winsock2.h>
+#ifndef WIN32_LEAN_AND_MEAN
+#define WIN32_LEAN_AND_MEAN
+#endif
+#include <Winsock2.h>
 #else
-# include <sys/time.h>
+#include <sys/time.h>
 #endif
 
 #include "utils.h"
 
-int main(int argc, char const *const *argv)
-{
+int main(int argc, char const *const *argv) {
   char const *hostname;
   int port;
   amqp_socket_t *socket;
@@ -68,7 +66,9 @@ int main(int argc, char const *const *argv)
   struct timeval *tv;
 
   if (argc < 3) {
-    fprintf(stderr, "Usage: amqp_connect_timeout host port [timeout_sec [timeout_usec=0]]\n");
+    fprintf(stderr,
+            "Usage: amqp_connect_timeout host port [timeout_sec "
+            "[timeout_usec=0]]\n");
     return 1;
   }
 
@@ -77,7 +77,7 @@ int main(int argc, char const *const *argv)
 
     tv->tv_sec = atoi(argv[3]);
 
-    if (argc > 4 ) {
+    if (argc > 4) {
       tv->tv_usec = atoi(argv[4]);
     } else {
       tv->tv_usec = 0;
@@ -87,7 +87,6 @@ int main(int argc, char const *const *argv)
     tv = NULL;
   }
 
-
   hostname = argv[1];
   port = atoi(argv[2]);
 
@@ -99,13 +98,17 @@ int main(int argc, char const *const *argv)
     die("creating TCP socket");
   }
 
-  die_on_error(amqp_socket_open_noblock(socket, hostname, port, tv), "opening TCP socket");
+  die_on_error(amqp_socket_open_noblock(socket, hostname, port, tv),
+               "opening TCP socket");
 
-  die_on_amqp_error(amqp_login(conn, "/", 0, 131072, 0, AMQP_SASL_METHOD_PLAIN, "guest", "guest"), "Logging in");
+  die_on_amqp_error(amqp_login(conn, "/", 0, 131072, 0, AMQP_SASL_METHOD_PLAIN,
+                               "guest", "guest"),
+                    "Logging in");
 
-  die_on_amqp_error(amqp_connection_close(conn, AMQP_REPLY_SUCCESS), "Closing connection");
+  die_on_amqp_error(amqp_connection_close(conn, AMQP_REPLY_SUCCESS),
+                    "Closing connection");
   die_on_error(amqp_destroy_connection(conn), "Ending connection");
 
-  printf ("Done\n");
+  printf("Done\n");
   return 0;
 }
