@@ -1,4 +1,3 @@
-/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * ***** BEGIN LICENSE BLOCK *****
  * Version: MIT
@@ -35,19 +34,17 @@
  */
 
 #include <stdint.h>
-#include <time.h>
 #include <sys/time.h>
+#include <time.h>
 #include <unistd.h>
 
-uint64_t now_microseconds(void)
-{
+uint64_t now_microseconds(void) {
   struct timeval tv;
   gettimeofday(&tv, NULL);
-  return (uint64_t) tv.tv_sec * 1000000 + (uint64_t) tv.tv_usec;
+  return (uint64_t)tv.tv_sec * 1000000 + (uint64_t)tv.tv_usec;
 }
 
-void microsleep(int usec)
-{
+void microsleep(int usec) {
   struct timespec req;
   req.tv_sec = 0;
   req.tv_nsec = 1000 * usec;
