@@ -1,4 +1,3 @@
-/* vim:set ft=c ts=2 sw=2 sts=2 et cindent: */
 /*
  * Portions created by Alan Antonuk are Copyright (c) 2013-2014 Alan Antonuk.
  * All Rights Reserved.
@@ -45,16 +44,11 @@ typedef enum {
   AMQP_SF_POLLERR = 8
 } amqp_socket_flag_enum;
 
-typedef enum {
-  AMQP_SC_NONE = 0,
-  AMQP_SC_FORCE = 1
-} amqp_socket_close_enum;
+typedef enum { AMQP_SC_NONE = 0, AMQP_SC_FORCE = 1 } amqp_socket_close_enum;
 
-int
-amqp_os_socket_error(void);
+int amqp_os_socket_error(void);
 
-int
-amqp_os_socket_close(int sockfd);
+int amqp_os_socket_close(int sockfd);
 
 /* Socket callbacks. */
 typedef ssize_t (*amqp_socket_send_fn)(void *, const void *, size_t, int);
@@ -79,7 +73,6 @@ struct amqp_socket_t_ {
   const struct amqp_socket_class_t *klass;
 };
 
-
 /**
  * Set set the socket object for a connection
  *
@@ -89,9 +82,7 @@ struct amqp_socket_t_ {
  * \param [in] state The connection object to add the socket to
  * \param [in] socket The socket object to assign to the connection
  */
-void
-amqp_set_socket(amqp_connection_state_t state, amqp_socket_t *socket);
-
+void amqp_set_socket(amqp_connection_state_t state, amqp_socket_t *socket);
 
 /**
  * Send a message from a socket.
@@ -108,8 +99,8 @@ amqp_set_socket(amqp_connection_state_t state, amqp_socket_t *socket);
  *
  * \return AMQP_STATUS_OK on success. amqp_status_enum value otherwise
  */
-ssize_t
-amqp_socket_send(amqp_socket_t *self, const void *buf, size_t len, int flags);
+ssize_t amqp_socket_send(amqp_socket_t *self, const void *buf, size_t len,
+                         int flags);
 
 ssize_t amqp_try_send(amqp_connection_state_t state, const void *buf,
                       size_t len, amqp_time_t deadline, int flags);
@@ -126,8 +117,7 @@ ssize_t amqp_try_send(amqp_connection_state_t state, const void *buf,
  *
  * \return The number of bytes received, or < 0 on error (\ref amqp_status_enum)
  */
-ssize_t
-amqp_socket_recv(amqp_socket_t *self, void *buf, size_t len, int flags);
+ssize_t amqp_socket_recv(amqp_socket_t *self, void *buf, size_t len, int flags);
 
 /**
  * Close a socket connection and free resources.
@@ -142,16 +132,14 @@ amqp_socket_recv(amqp_socket_t *self, void *buf, size_t len, int flags);
  *
  * \return Zero upon success, non-zero otherwise.
  */
-int
-amqp_socket_close(amqp_socket_t *self, amqp_socket_close_enum force);
+int amqp_socket_close(amqp_socket_t *self, amqp_socket_close_enum force);
 
 /**
  * Destroy a socket object
  *
  * \param [in] self the socket object to delete
  */
-void
-amqp_socket_delete(amqp_socket_t *self);
+void amqp_socket_delete(amqp_socket_t *self);
 
 /**
  * Open a socket connection.
@@ -163,12 +151,13 @@ amqp_socket_delete(amqp_socket_t *self);
  *
  * \param [in] host Connect to this host.
  * \param [in] port Connect on this remote port.
- * \param [in] timeout Max allowed time to spent on opening. If NULL - run in blocking mode
+ * \param [in] timeout Max allowed time to spent on opening. If NULL - run in
+ * blocking mode
  *
  * \return File descriptor upon success, non-zero negative error code otherwise.
  */
-int
-amqp_open_socket_noblock(char const *hostname, int portnumber, struct timeval *timeout);
+int amqp_open_socket_noblock(char const *hostname, int portnumber,
+                             struct timeval *timeout);
 
 int amqp_open_socket_inner(char const *hostname, int portnumber,
                            amqp_time_t deadline);
@@ -179,20 +168,18 @@ int amqp_poll(int fd, int event, amqp_time_t deadline);
 
 int amqp_send_method_inner(amqp_connection_state_t state,
                            amqp_channel_t channel, amqp_method_number_t id,
-                           void *decoded, int flags);
-int
-amqp_queue_frame(amqp_connection_state_t state, amqp_frame_t *frame);
+                           void *decoded, int flags, amqp_time_t deadline);
 
-int
-amqp_put_back_frame(amqp_connection_state_t state, amqp_frame_t *frame);
+int amqp_queue_frame(amqp_connection_state_t state, amqp_frame_t *frame);
 
-int
-amqp_simple_wait_frame_on_channel(amqp_connection_state_t state,
-                                  amqp_channel_t channel,
-                                  amqp_frame_t *decoded_frame);
+int amqp_put_back_frame(amqp_connection_state_t state, amqp_frame_t *frame);
 
-int
-sasl_mechanism_in_list(amqp_bytes_t mechanisms, amqp_sasl_method_enum method);
+int amqp_simple_wait_frame_on_channel(amqp_connection_state_t state,
+                                      amqp_channel_t channel,
+                                      amqp_frame_t *decoded_frame);
+
+int sasl_mechanism_in_list(amqp_bytes_t mechanisms,
+                           amqp_sasl_method_enum method);
 
 int amqp_merge_capabilities(const amqp_table_t *base, const amqp_table_t *add,
                             amqp_table_t *result, amqp_pool_t *pool);
